import { select, layout, json } from 'd3';

const width = 960,
  height = 500;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const force = layout
  .force()
  .gravity(0.1)
  .distance(200)
  .charge(-600)
  .size([width, height]);

const data = json('data.json', function (json) {
  force.nodes(json.nodes).links(json.links).start();

  const link = svg
    .selectAll('.link')
    .data(json.links)
    .enter()
    .append('line')
    .attr('class', 'link')
    .style('stroke-width', function (d) {
      return d.weight;
    });

  const node = svg
    .selectAll('.node')
    .data(json.nodes)
    .enter()
    .append('g')
    .attr('class', 'node')
    .call(force.drag);

  node.append('circle').attr('r', '15');

  node
    .append('text')
    .attr('dx', 15)
    .attr('dy', '.5em')
    .text(function (d) {
      return d.name;
    });

  force.on('tick', function () {
    link
      .attr('x1', function (d) {
        return d.source.x;
      })
      .attr('y1', function (d) {
        return d.source.y;
      })
      .attr('x2', function (d) {
        return d.target.x;
      })
      .attr('y2', function (d) {
        return d.target.y;
      });

    node.attr('transform', function (d) {
      return 'translate(' + d.x + ',' + d.y + ')';
    });
  });
});
